@@ -28,6 +28,17 @@ pub enum HmacError {
     MacError,
 }
 
+/// Stream cipher algorithm errors.
+#[derive(Debug, Error)]
+pub enum StreamCipherError {
+    /// The error returned when key or nonce used in stream cipher
+    /// has an invalid length.
+    InvalidLength,
+
+    /// The error returned when cipher reached the end of stream.
+    LoopError,
+}
+
 /// Errors which may occur while processing signatures.
 #[derive(Debug, Error, PartialEq)]
 pub enum SignatureError {
