@@ -1,12 +1,22 @@
 //! SHA-512 based HMAC.
 
+use core::mem::ManuallyDrop;
+
 use hmac::Mac;
 use sha2::Sha512;
+use zeroize::Zeroize;
 
 use crate::errors::HmacError;
 
 /// SHA-512 based HMAC.
-pub struct Hmac(hmac::Hmac<Sha512>);
+#[derive(Zeroize)]
+pub struct Hmac(#[zeroize(skip)] ManuallyDrop<hmac::Hmac<Sha512>>);
+
+impl Drop for Hmac {
+    fn drop(&mut self) {
+        unsafe { ManuallyDrop::drop(&mut self.0) }
+    }
+}
 
 impl cryptraits::hmac::Hmac for Hmac {
     type E = HmacError;
@@ -16,19 +26,28 @@ impl cryptraits::hmac::Hmac for Hmac {
         Self: Sized,
     {
         let hmac = hmac::Hmac::new_from_slice(key).or(Err(HmacError::InvalidLength))?;
-        Ok(Self(hmac))
+        Ok(Self(ManuallyDrop::new(hmac)))
     }
 
     fn update(&mut self, data: &[u8]) {
         self.0.update(data);
     }
 
-    fn verify_slice(self, tag: &[u8]) -> Result<(), Self::E> {
-        self.0.verify_slice(tag).or(Err(HmacError::MacError))
+    fn verify_slice(mut self, tag: &[u8]) -> Result<(), Self::E> {
+        unsafe {
+            ManuallyDrop::take(&mut self.0)
+                .verify_slice(tag)
+                .or(Err(HmacError::MacError))
+        }
     }
 
-    fn finalize(self) -> Vec<u8> {
-        self.0.finalize().into_bytes().to_vec()
+    fn finalize(mut self) -> Vec<u8> {
+        unsafe {
+            ManuallyDrop::take(&mut self.0)
+                .finalize()
+                .into_bytes()
+                .to_vec()
+        }
     }
 }
 
